package org.ananas.mac.menu;

/*
 * Copyright 2003, Benoit Marchal. All rights reserved.
 * Distributed under the artistic license (open source).
 * See www.ananas.org for licensing information.
 */

import java.awt.*;
import javax.swing.*;
import java.awt.event.*;

class JavaItem
   implements ApplicationItem
{
   private MenuItem item = null;
   private JMenuItem jitem = null;

   public void register(String label,Menu menu)
      throws IllegalStateException
   {
      register(label,null,menu);
   }
   
   public void register(String label,MenuShortcut shortcut,Menu menu)
      throws IllegalStateException
   {
      if(item != null || jitem != null)
         throw new IllegalStateException(ApplicationItemFactory.resources.getString("registered"));
      else
      {
         item = new MenuItem(label,shortcut);
         menu.add(item);
      }
   }
   
   public void register(String label,JMenu menu)
      throws IllegalStateException
   {
      register(label,null,null,menu);
   }

   public void register(Icon icon,JMenu menu)
      throws IllegalStateException
   {
      register(null,icon,null,menu);
   }
   
   public void register(String label,Icon icon,JMenu menu)
      throws IllegalStateException
   {
      register(label,icon,null,menu);
   }
   
   public void register(String label,int mnemonic,JMenu menu)
      throws IllegalStateException
   {
      register(label,mnemonic,null,menu);
   }
   
   public void register(String label,KeyStroke accelerator,JMenu menu)
      throws IllegalStateException
   {
      register(label,null,accelerator,menu);
   }
   
   public void register(Icon icon,KeyStroke accelerator,JMenu menu)
      throws IllegalStateException
   {
      register(null,icon,accelerator,menu);
   }
   
   public void register(String label,Icon icon,KeyStroke accelerator,JMenu menu)
      throws IllegalStateException
   {
      if(item != null || jitem != null)
         throw new IllegalStateException(ApplicationItemFactory.resources.getString("registered"));
      else
      {
         jitem = new JMenuItem(label,icon);
         if(accelerator != null)
            jitem.setAccelerator(accelerator);
         menu.add(jitem);
      }
   }
   public void register(String label,int mnemonic,KeyStroke accelerator,JMenu menu)
      throws IllegalStateException
   {
      if(item != null || jitem != null)
         throw new IllegalStateException(ApplicationItemFactory.resources.getString("registered"));
      else
      {
         jitem = new JMenuItem(label,mnemonic);
         if(accelerator != null)
            jitem.setAccelerator(accelerator);
         menu.add(jitem);
      }
   }
   
   public void addActionListener(ActionListener listener)
      throws IllegalStateException
   {
      if(item != null)
         item.addActionListener(listener);
      else if(jitem != null)
         jitem.addActionListener(listener);
      else
         throw new IllegalStateException(ApplicationItemFactory.resources.getString("not.registered"));
   }
   
   public void removeActionListener(ActionListener listener)
      throws IllegalStateException
   {
      if(item != null)
         item.removeActionListener(listener);
      else if(jitem != null)
         jitem.removeActionListener(listener);
      else
         throw new IllegalStateException(ApplicationItemFactory.resources.getString("not.registered"));
   }
   
   public boolean isAddedToMenu()
   {
      return true;
   }
}