<?xml version="1.0"?>
<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:xm="http://www.ananas.org/2001/XM/Walk/Directory"
                xmlns:xl="http://www.ananas.org/2001/XM/Walk/Link"
                xmlns:db="http://www.psol.com/2001/docbook"
                exclude-result-prefixes="xm">

<xsl:import href="default.xsl"/>

<xsl:output method="html"/>

<!-- work around a bug in Xalan, it uses the localized default,
     not those specified in the XSLT recommendation -->
<xsl:decimal-format name="w3c-default"
                    decimal-separator="."
                    grouping-separator=","
                    zero-digit="0"
                    digit="#"/>

<xsl:template match="xm:Directory">
   <table border="0">
      <tr>
         <td><xsl:text disable-output-escaping="yes"><![CDATA[&nbsp;]]></xsl:text></td>
         <td>File name</td>
         <td><xsl:text disable-output-escaping="yes"><![CDATA[&nbsp;]]></xsl:text></td>
         <td>Last modified</td>
         <td><xsl:text disable-output-escaping="yes"><![CDATA[&nbsp;]]></xsl:text></td>
         <td align="left">Size</td>
      </tr>
      <tr>
         <td><img src="!images/icons/up.gif" align="absmiddle" height="22" width="27"/></td>
         <td><a href="!xm/index.xml">Parent directory</a></td>
      </tr>
      <xsl:apply-templates>
         <xsl:sort select="." order="ascending"/>
      </xsl:apply-templates>
   </table>
</xsl:template>

<xsl:template match="xm:File[@isFile='true' and @isHidden='false']">
   <xsl:variable name="last4" select="substring(.,string-length(.) - 3)"/>
   <tr>
      <td valign="top"><xsl:choose>
         <xsl:when test="$last4='.zip'">
            <img src="!images/icons/zip.gif" with="20" height="22"/>
         </xsl:when>
         <xsl:otherwise>
            <img src="!images/icons/any.gif" with="20" height="22"/>
         </xsl:otherwise>
      </xsl:choose></td>
      <td valign="top"><a href="{.}"><xl:Fix><xsl:apply-templates/></xl:Fix></a></td>
      <td><xsl:text disable-output-escaping="yes"><![CDATA[&nbsp;]]></xsl:text></td>
      <td valign="top"><xsl:call-template name="format-date">
         <xsl:with-param name="date" select="@lastModified"/>
      </xsl:call-template></td>
      <td><xsl:text disable-output-escaping="yes"><![CDATA[&nbsp;]]></xsl:text></td>
      <td valign="top" align="right"><xsl:call-template name="format-length">
         <xsl:with-param name="length" select="@length"/>
      </xsl:call-template></td>
   </tr>
</xsl:template>

<xsl:template match="xm:File[@isMarked='true']"/>

<xsl:template name="format-date">
   <xsl:param name="date"/>
   <xsl:variable name="month" select="substring($date,6,2)"/>
   <xsl:value-of select="substring($date,9,2)"/>
   <xsl:choose>
      <xsl:when test="$month='01'"><xsl:text> Jan. </xsl:text></xsl:when>
      <xsl:when test="$month='02'"><xsl:text> Feb. </xsl:text></xsl:when>
      <xsl:when test="$month='03'"><xsl:text> Mar. </xsl:text></xsl:when>
      <xsl:when test="$month='04'"><xsl:text> Apr. </xsl:text></xsl:when>
      <xsl:when test="$month='05'"><xsl:text> May </xsl:text></xsl:when>
      <xsl:when test="$month='06'"><xsl:text> Jun. </xsl:text></xsl:when>
      <xsl:when test="$month='07'"><xsl:text> Jul. </xsl:text></xsl:when>
      <xsl:when test="$month='08'"><xsl:text> Aug. </xsl:text></xsl:when>
      <xsl:when test="$month='09'"><xsl:text> Sep. </xsl:text></xsl:when>
      <xsl:when test="$month='10'"><xsl:text> Oct. </xsl:text></xsl:when>
      <xsl:when test="$month='11'"><xsl:text> Nov. </xsl:text></xsl:when>
      <xsl:otherwise><xsl:text> Dec. </xsl:text></xsl:otherwise>
   </xsl:choose>
   <xsl:value-of select="substring($date,1,4)"/>
</xsl:template>

<xsl:template name="format-length">
   <xsl:param name="length"/>
   <xsl:variable name="kb" select="number($length) div 1024"/>
   <xsl:variable name="mb" select="$kb div 1024"/>
   <xsl:choose>
      <xsl:when test="$mb &gt; 0.5"><xsl:value-of select="format-number($mb,'#,###.#','w3c-default')"/>M</xsl:when>
      <xsl:when test="floor($kb) &gt; 0"><xsl:value-of select="round($kb)"/>K</xsl:when>
      <xsl:otherwise><xsl:value-of select="$length"/>b</xsl:otherwise>
   </xsl:choose>
</xsl:template>

</xsl:stylesheet>
