/**
 * Specify how to move a file from the XML acquisition directory
 * to the publishing/HTML/other one. Implementations perform actual
 * styling/copying operations.
 *
 * @author <a href="http://www.marchal.com">Beno&#238;t Marchal</a>
 */

// Copyright 2001, Benot Marchal.

package org.ananas.xm;

import java.io.*;

public interface Mover
{
   /**
    * our own property to set the source file in XMLFilter
    */
   public final static String SOURCE_FILE =
      "http://www.ananas.org/2001/XM/Properties/SourceFile";

   /**
    * Move one file.
    * @param sourceFile the file to style
    * @param targetDir the directory to copy the result to
    * @param depth how far we are from the root of the target file
    *   system (it cannot be infered from targetDir as there might
    *   one or more levels which are not part of the published stuff)
    *   0 = root level, 1 = one directory under the root, etc.
    * @return new file or null if the file was ignored
    */
   public File move(File sourceFile,File targetDir,int depth)
      throws IOException, XMException;

   /**
    * Return the name (excluding path) the file would have after moving.
    * This is useful because some movers renamed files (e.g. change the
    * extension).
    * @param file file the mover would have to move
    * @return the extension it would give the file in the target directory
    */
   public String getTargetName(File file)
      throws XMException;
}
