package org.ananas.xm.eclipse;

import java.io.*;
import java.util.Map;
import org.ananas.xm.*;
import org.eclipse.ui.*;
import org.eclipse.core.runtime.*;
import org.eclipse.core.resources.*;
import org.eclipse.jface.dialogs.ErrorDialog;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.swt.widgets.Display;

public class IncrementalBuilderDemo
   extends IncrementalProjectBuilder
{
   private IWorkbench workbench;
   
   private class Visitor
      implements IResourceDeltaVisitor
   {
      Messenger messenger;
      
      public Visitor(Messenger messenger)
      {
         this.messenger = messenger;
      }
      
      public boolean visit(IResourceDelta delta)
         throws CoreException
      {
      	 try
      	 {
            Object[] path = new Object[]
         	{
         	   delta.getResource().getProjectRelativePath().toOSString(),
      	    };
            switch(delta.getKind())
            {
               case IResourceDelta.ADDED:
                  messenger.info("Resource {0} added.",path);
                  break;
               case IResourceDelta.REMOVED:
                  messenger.info("Resource {0} removed.",path);
                  break;
               case IResourceDelta.CHANGED:
                  messenger.info("Resource {0} changed.",path);
                  break;
               default:
                  messenger.fatal(new XMException("Unknown delta type"));
            }
            return true;
      	 }
      	 catch(XMException x)
      	 {
      	 	throw new CoreException(PluginTools.makeStatus(x)); 
      	 }
      }
   }
   
   public IncrementalBuilderDemo()
   {
      workbench = PlatformUI.getWorkbench();
   }
	
   protected IProject[] build(int kind,Map args,IProgressMonitor _monitor)
   {
      try
      {
         IProject project = getProject();
         if(project != null && project.isAccessible())
         {
            if(_monitor == null)
               _monitor = new NullProgressMonitor();
            MessengerProxy proxy = new MessengerProxy();
            MessengerView console = MessengerView.showConsole(workbench);
            if(console != null)
            {
               console.clean();
               proxy.addMessenger(console);
            }
            MessengerMonitor monitor = new MessengerMonitor(_monitor,"Publish XML documents");
            proxy.addMessenger(monitor);
            switch(kind)
            {
            	case INCREMENTAL_BUILD:
            	   proxy.info("INCREMENTAL_BUILD requested");
                   incrementalBuild(proxy);
                   break;
            	case AUTO_BUILD:
            	   proxy.info("AUTO_BUILD requested");
                   incrementalBuild(proxy);
                   break;
            	case FULL_BUILD:
            	   proxy.info("FULL_BUILD requested");
                   break;
                default:
            	   proxy.fatal(new XMException("unknown build kind requested"));
            }
         }
      }
      catch(Exception x)
      {
         ErrorDialog.openError(workbench.getActiveWorkbenchWindow().getShell(),
                               Resources.getString("eclipse.dialogtitle"),
                               Resources.getString("eclipse.builderror"),
                               PluginTools.makeStatus(x));
      }
      return new IProject[0]; 
   }

   private void incrementalBuild(Messenger messenger)
      throws CoreException, IOException, XMException
   {
      IResourceDelta delta = getDelta(getProject());
      if(delta != null)
         delta.accept(new Visitor(messenger));
      else
         messenger.info("Delta is empty (null)");
   }
}