package org.ananas.xm.eclipse;

import org.eclipse.core.runtime.QualifiedName;

/**
 * A placeholder for the various constants needed throughout the plugin
 * project. Most of these are references to ids defined in the plugin.xml
 * file.
 * @author bmarchal
 */
public interface PluginConstants
{ 
   /**
    * plugin id from plugin.xml
    */
   public static final String PLUGIN_ID = "org.ananas.xm.eclipse";
   
   /**
    * console (MessengerView) id from plugin.xml
    */
   public static final String CONSOLE_ID = "org.ananas.xm.eclipse.views.console";
   
   /**
    * XM Builder id from plugin.xml
    */
   public static final String BUILDER_ID = "org.ananas.xm.eclipse.xmbuilder";
   
   /**
    * XM project nature (for .project)
    */
   public static final String NATURE_ID = "org.ananas.xm.eclipse.xmnature";

   /**
    * namespace URI for the properties
    */
   public static final String PROPERTY_NAMESPACE = "http://ananas.org/2002/xm/eclipse";
   
   /**
    * property local name for the source directory
    */
   public static final String SOURCE_PROPERTY = "source";
   
   /**
    * property local name for the publish directory
    */
   public static final String PUBLISH_PROPERTY = "publish";

   /**
    * property local name for the rules directory
    */
   public static final String RULES_PROPERTY = "rules";

   /**
    * property local name for the build status
    */
   public static final String BUILD_PROPERTY = "build";

   /**
    * property qualified name for the source directory
    */
   public static final QualifiedName SOURCE_PROPERTY_NAME =
      new QualifiedName(PROPERTY_NAMESPACE,SOURCE_PROPERTY);

   /**
    * property qualified name for the publish directory
    */
   public static final QualifiedName PUBLISH_PROPERTY_NAME =
      new QualifiedName(PROPERTY_NAMESPACE,PUBLISH_PROPERTY);

   /**
    * property qualified name for the rules directory
    */
   public static final QualifiedName RULES_PROPERTY_NAME =
      new QualifiedName(PROPERTY_NAMESPACE,RULES_PROPERTY);

   /**
    * property qualified name for the build status
    */
   public static final QualifiedName BUILD_PROPERTY_NAME =
      new QualifiedName(PROPERTY_NAMESPACE,BUILD_PROPERTY);

   /**
    * preference name for the console level
    */
   public static final String LEVEL_PREFERENCE_NAME = "level";
   
   /**
    * preference value for the console level, show all messages
    * fatal, error, warning, info, progress
    */
   public static final String LEVEL_ALL = "all";
   
   /**
    * preference value for the console level, show all but progress messages
    * fatal, error, warning, info
    */
   public static final String LEVEL_INFO = "info";

   /**
    * preference value for the console level, show error & warning messages
    * fatal, error, warning
    */
   public static final String LEVEL_WARNING = "warning";

   /**
    * preference value for the console level, show error messages
    * fatal, error
    */
   public static final String LEVEL_ERROR = "error";

   /**
    * default value for the source directory name
    */
   public static final String DEFAULT_SOURCE_DIR = "src";

   /**
    * default value for the rules directory name
    */
   public static final String DEFAULT_RULES_DIR = "rules";
   
   /**
    * default value for the publish directory name
    */
   public static final String DEFAULT_PUBLISH_DIR = "publish";   

   /**
    * default value for the build selection in the properties
    */
   public static final boolean DEFAULT_BUILD_VALUE = true;
}