package org.ananas.xm.eclipse;

import org.eclipse.core.runtime.*;
import org.xml.sax.SAXException;
import org.ananas.xm.XMException;
import javax.xml.transform.TransformerException;

/**
 * Utility methods for the project. This is where I place methods that
 * are not tied to a specific class.
 * 
 * @author bmarchal
 */
class PluginTools
{
   /**
    * Create an IStatus object from an exception.
    * @param x exception to process
    * @return IStatus status object for the above exception
    */
   public static IStatus makeStatus(Exception x)
   {
      Throwable t = popThrowables(x);
      if(t instanceof CoreException)
         return ((CoreException)t).getStatus();
      else
         return new Status(IStatus.ERROR,
                            PluginConstants.PLUGIN_ID,
                            IStatus.ERROR,
                            x.getMessage() != null ? x.getMessage()
                                                   : x.toString(),
                            t);
   }

   /**
    * A helpful method (I hope). It walks through exceptions
    * chains until it reaches the original one.
    * Indeed it's not uncommon for TransformerException or
    * SAXException to hold another exception that itself may 
    * hold another exception.
    * The result? Unreadable error messages where the original
    * error (say ArrayOutOfBoundsException) is lost in a sea
    * of TransformerException.
    * @param t exception to process
    * @return original exception, if any
    */
   public static Throwable popThrowables(Throwable t)
   {
      if(t instanceof XMException)
      {
         if(((XMException)t).getException() != null)
            return popThrowables(((XMException)t).getException());
      }
      else if(t instanceof TransformerException)
      {
         if(((TransformerException)t).getCause() != null)
            return popThrowables(((TransformerException)t).getCause());
      }   
      else if(t instanceof SAXException)
      {
         if(((SAXException)t).getException() != null)
            return popThrowables(((SAXException)t).getException());
      }
      return t;
   }
}