package org.ananas.xm.eclipse;

import org.eclipse.core.runtime.*;
// import org.eclipse.jface.dialogs.*;
import org.eclipse.core.resources.*;

/**
 * @author bmarchal
 */
public class ProjectProperties
   implements PluginConstants
{
   private IProject project;

   private static final String DEFAULT_BUILD = String.valueOf(DEFAULT_BUILD_VALUE);

   public ProjectProperties(IProject project)
   {
      this.project = project;
   }
   
   public String getSource()
      throws CoreException
   {
      return getProperty(SOURCE_PROPERTY_NAME,DEFAULT_SOURCE_DIR);
   }
   
   public String getRules()
      throws CoreException
   {
      return getProperty(RULES_PROPERTY_NAME,DEFAULT_RULES_DIR);
   }
   
   public String getPublish()
      throws CoreException
   {
      return getProperty(PUBLISH_PROPERTY_NAME,DEFAULT_PUBLISH_DIR);
   }

   public boolean isBuild()
      throws CoreException
   {
      String st = getProperty(BUILD_PROPERTY_NAME,DEFAULT_BUILD);
      return Boolean.valueOf(st).booleanValue();
   }

   public boolean hasNature()
      throws CoreException
   {
      return project.hasNature(NATURE_ID);
   }

   public void setSource(String source)
      throws CoreException
   {
      setProperty(SOURCE_PROPERTY_NAME,source,DEFAULT_SOURCE_DIR);
   }
   
   public void setRules(String rules)
      throws CoreException
   {
      setProperty(RULES_PROPERTY_NAME,rules,DEFAULT_RULES_DIR);
   }
   
   public void setPublish(String publish)
      throws CoreException
   {
      setProperty(PUBLISH_PROPERTY_NAME,publish,DEFAULT_PUBLISH_DIR);
   }

   public void setBuild(boolean build)
      throws CoreException
   {
      setProperty(BUILD_PROPERTY_NAME,String.valueOf(build),DEFAULT_BUILD);
   }
   
   /*
   public void setNature(boolean nature)
      throws CoreException
    {
       if(nature != hasNature())
          try
          {
             ProgressMonitorDialog dialog = new ProgressMonitorDialog(part.getSite().getShell());
             dialog.run(false,true,new IRunnableWithProgress()
             {
                public void run(IProgressMonitor monitor)
                {
                   try
                   {
                      setProjectNature(monitor);
                   }
                   catch(CoreException x)
                   {
                      reportError(x);
                   }
                }
             });
          }
          catch(InterruptedException x)
          {
             reportError(x);
          }
          catch(InvocationTargetException x)
          {
             reportError(x);
          }
   }*/

   public void setNature(boolean nature)
      throws CoreException
   {
   	  if(nature)
   	  {
   	     if(!hasNature())
         {
            IProjectDescription description = project.getDescription();
            String[] old = description.getNatureIds(),
                     natures= new String[old.length + 1];
            System.arraycopy(old,0,natures,0,old.length);
            natures[old.length] = NATURE_ID;
            description.setNatureIds(natures);
            project.setDescription(description,new NullProgressMonitor());
         }
   	  }
   	  else
   	  {
   	     if(hasNature())
   	     {
            IProjectDescription description = project.getDescription();
            String[] old = description.getNatureIds(),
                     natures= new String[old.length - 1];
            int i = 0,
                 j = 0;
            while(i < old.length)
            {
               if(!old[i].equals(NATURE_ID))
                  natures[j++] = old[i];
               i++;
            }
            description.setNatureIds(natures);
            project.setDescription(description,new NullProgressMonitor());
   	     }
   	  }
   }

   protected String getProperty(QualifiedName key,String def)
      throws CoreException
   {
      String value = project.getPersistentProperty(key);
      if(value == null || value.length() == 0)
         return def;
      else
         return value;
   }

   protected void setProperty(QualifiedName key,String value,String def)
      throws CoreException
   {
   	   if(value != null && value.length() != 0 && hasNature())
   	   {
   	      if(value.equals(def))
   	         project.setPersistentProperty(key,null);
   	      else
   	         project.setPersistentProperty(key,value);
   	   }
   }
}