package org.ananas.xm.eclipse;

import org.eclipse.core.runtime.*;
import org.eclipse.core.resources.*;

/**
 * @author bmarchal
 */
public class XMProjectNature
   implements IProjectNature, PluginConstants
{
   private IProject project;
   
   public void configure()
      throws CoreException
   {
   	  IProjectDescription description = project.getDescription();
   	  if(!hasBuildSpec(description.getBuildSpec()))
   	  {
   	     ICommand[] old = description.getBuildSpec(),
   	                specs = new ICommand[old.length + 1];
         System.arraycopy(old,0,specs,0,old.length);
         ICommand command = description.newCommand();
         command.setBuilderName(BUILDER_ID);
         specs[old.length] = command;
         description.setBuildSpec(specs);
         project.setDescription(description,new NullProgressMonitor());
   	  }
   }

   // should we erase the XM properties, if any?
   public void deconfigure()
      throws CoreException
   {
   	  IProjectDescription description = project.getDescription();
   	  int count = getBuildSpecCount(description.getBuildSpec());
   	  if(count != 0)
   	  {
   	     ICommand[] old = description.getBuildSpec(),
   	                specs = new ICommand[old.length - count];
   	     int i = 0,
   	         j = 0;
   	     while(i < old.length)
   	     {
   	        if(!old[i].getBuilderName().equals(BUILDER_ID))
   	           specs[i] = old[j++];
   	        i++;
   	     }
   	     description.setBuildSpec(specs);
         project.setDescription(description,new NullProgressMonitor());
   	  }
   }
   
   public IProject getProject()
   {
      return project;
   }
   
   public void setProject(IProject project)
   {
   	  this.project = project;
   }

   private boolean hasBuildSpec(ICommand[] commands)
   {
      return getBuildSpecCount(commands) != 0;
   }
   
   private int getBuildSpecCount(ICommand[] commands)
   {
   	  int count = 0;
   	  for(int i = 0;i < commands.length;i++)
   	     if(commands[i].getBuilderName().equals(BUILDER_ID))
   	        count++;
   	  return count;
   }
}