package org.ananas.xm.eclipse;

import org.ananas.xm.*;
import org.eclipse.ui.*;
import org.eclipse.swt.*;
import org.eclipse.swt.events.*;
import org.eclipse.swt.layout.*; 
import org.eclipse.ui.dialogs.*;
import org.eclipse.swt.widgets.*;
import org.eclipse	.core.runtime.*;
import org.eclipse.jface.dialogs.*;
import org.eclipse.core.resources.*;

/**
 * This page will be added to the property page dialog
 * when the "Properties..." popup menu item is selected
 * for XM projects. 
 * @author bmarchal
 */
public class XMProjectPropertiesPage
   extends PropertyPage
   implements PluginConstants
{
   private Text srcText,
                 rulesText,
                 publishText;
   private Button hasNature,
                   isBuild;
   private Group group;
   private ProjectProperties properties;
	
   private Control buildUI(Composite parent)
   {
      Composite composite = new Composite(parent,SWT.NULL);
      RowLayout rowLayout = new RowLayout();
      rowLayout.type = SWT.VERTICAL;
      rowLayout.wrap = false;
      composite.setLayout(rowLayout);
      hasNature = new Button(composite,SWT.CHECK);
      hasNature.setText(Resources.getString("eclipse.hasnature"));
      hasNature.addSelectionListener(new SelectionListener()
      {
         public void widgetDefaultSelected(SelectionEvent e)
         {
            group.setEnabled(hasNature.getSelection());
         }
         
         public void widgetSelected(SelectionEvent e)
         {
         	group.setEnabled(hasNature.getSelection());
         }
      });
      group = new Group(composite,SWT.NONE);
      group.setText(Resources.getString("eclipse.properties"));
      GridLayout gridLayout = new GridLayout();
      gridLayout.numColumns = 2;
      group.setLayout(gridLayout);
      Label label = new Label(group,SWT.RIGHT);
      label.setText(Resources.getString("eclipse.src"));
      srcText = new Text(group,SWT.SINGLE);
      GridData gridData = new GridData();
      gridData.widthHint = 150;
      srcText.setLayoutData(gridData);
      label = new Label(group,SWT.RIGHT);
      label.setText(Resources.getString("eclipse.rules"));
      rulesText = new Text(group,SWT.LEFT);
      gridData = new GridData();
      gridData.horizontalAlignment = GridData.FILL;
      gridData.grabExcessHorizontalSpace = true;
      rulesText.setLayoutData(gridData);
      label = new Label(group,SWT.RIGHT);
      label.setText(Resources.getString("eclipse.publish"));
      publishText = new Text(group,SWT.LEFT);
      gridData = new GridData();
      publishText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL | GridData.GRAB_HORIZONTAL));
      isBuild = new Button(group,SWT.CHECK);
      isBuild.setText(Resources.getString("eclipse.build"));
      gridData = new GridData();
      gridData.horizontalSpan = 2;
      isBuild.setLayoutData(gridData);
      return composite;
   }

   public void readProperties()
      throws CoreException
   {
   	   srcText.setText(properties.getSource());
   	   rulesText.setText(properties.getRules());
   	   publishText.setText(properties.getPublish());
   	   isBuild.setSelection(properties.isBuild());
   	   hasNature.setSelection(properties.hasNature());
   	   group.setEnabled(hasNature.getSelection());
   }

   public void writeProperties()
      throws CoreException
   {
      properties.setNature(hasNature.getSelection());
      properties.setSource(srcText.getText());
      properties.setRules(rulesText.getText());
      properties.setPublish(publishText.getText());
      properties.setBuild(isBuild.getSelection());
   }

   public Control createContents(Composite parent)
   {
   	  Control control = buildUI(parent);
      try
      {
         IAdaptable adaptable = getElement();
         if(adaptable instanceof IProject)
         {
         	properties = new ProjectProperties((IProject)adaptable);
            readProperties();
         }
      }
      catch(CoreException x)
      {
         ErrorDialog.openError(PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell(),
                               Resources.getString("eclipse.dialogtitle"),
                               Resources.getString("eclipse.propertyerror"),
                               PluginTools.makeStatus(x));
      }
      return control;
   }
   
   public boolean performOk()
   {
      try
      {
         writeProperties();
      }
      catch(CoreException x)
      {
         ErrorDialog.openError(PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell(),
                               Resources.getString("eclipse.dialogtitle"),
                               Resources.getString("eclipse.propertyerror"),
                               PluginTools.makeStatus(x));
      }
      return super.performOk();
   }

   public void performApply()
   {
      try
      {
         writeProperties();
      }
      catch(CoreException x)
      {
         ErrorDialog.openError(PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell(),
                               Resources.getString("eclipse.dialogtitle"),
                               Resources.getString("eclipse.propertyerror"),
                               PluginTools.makeStatus(x));
      }
      super.performApply();
   }

   public void performDefaults()
   {
      hasNature.setSelection(true);
      srcText.setText(DEFAULT_SOURCE_DIR);
      rulesText.setText(DEFAULT_RULES_DIR);
      publishText.setText(DEFAULT_PUBLISH_DIR);
      isBuild.setSelection(DEFAULT_BUILD_VALUE);
      super.performDefaults();
   }
}